==> pgadmin3-1.10.0.tar.gz: pgadmin3-1.10.0/pgadmin/debugger/ctlMessageWindow.cpp <==
//////////////////////////////////////////////////////////////////////////
//
// pgAdmin III - PostgreSQL Tools
// RCS-ID:      $Id: ctlMessageWindow.cpp 7758 2009-03-26 20:49:59Z dpage $
// Copyright (C) 2002 - 2009, The pgAdmin Development Team
// This software is released under the BSD Licence
//
// ctlMessageWindow.cpp - debugger 
//
//////////////////////////////////////////////////////////////////////////

#include "pgAdmin3.h"

// wxWindows headers
#include <wx/wx.h>

// App headers
#include "debugger/ctlMessageWindow.h"

IMPLEMENT_CLASS( ctlMessageWindow, wxTextCtrl )

////////////////////////////////////////////////////////////////////////////////
// ctlMessageWindow constructor
//
//  Initialize the grid control and clear it out....
//

ctlMessageWindow::ctlMessageWindow( wxWindow * parent, wxWindowID id )
    : wxTextCtrl( parent, wxID_ANY, _T(""), wxPoint(0, 0), wxSize(0, 0),
                               wxTE_MULTILINE | wxTE_READONLY)
{
    SetFont(settings->GetSQLFont());
}

////////////////////////////////////////////////////////////////////////////////
// addMessage()
//
//    Adds the message in the 'DBMS Messages' window.  
//

void ctlMessageWindow::addMessage( wxString message )
{
    AppendText(message + wxT("\n"));
}

////////////////////////////////////////////////////////////////////////////////
// delMessage()
//
//    Removes the given message from the 'DBMS Messages' window.
//

void ctlMessageWindow::delMessage( const char * name )
{
    SetValue(wxT(""));
}


wxString ctlMessageWindow::getMessage( int row )
{
    return( GetValue());
}

==> pgadmin3-1.10.1.tar.gz: pgadmin3-1.10.1/pgadmin/debugger/ctlMessageWindow.cpp <==
//////////////////////////////////////////////////////////////////////////
//
// pgAdmin III - PostgreSQL Tools
// RCS-ID:      $Id: ctlMessageWindow.cpp 8100 2009-12-02 12:31:00Z dpage $
// Copyright (C) 2002 - 2009, The pgAdmin Development Team
// This software is released under the BSD Licence
//
// ctlMessageWindow.cpp - debugger 
//
//////////////////////////////////////////////////////////////////////////

#include "pgAdmin3.h"

// wxWindows headers
#include <wx/wx.h>

// App headers
#include "debugger/ctlMessageWindow.h"

IMPLEMENT_CLASS( ctlMessageWindow, wxTextCtrl )

////////////////////////////////////////////////////////////////////////////////
// ctlMessageWindow constructor
//
//  Initialize the grid control and clear it out....
//

ctlMessageWindow::ctlMessageWindow( wxWindow * parent, wxWindowID id )
    : wxTextCtrl( parent, wxID_ANY, wxT(""), wxPoint(0, 0), wxSize(0, 0),
                               wxTE_MULTILINE | wxTE_READONLY)
{
    SetFont(settings->GetSQLFont());
}

////////////////////////////////////////////////////////////////////////////////
// addMessage()
//
//    Adds the message in the 'DBMS Messages' window.  
//

void ctlMessageWindow::addMessage( wxString message )
{
    AppendText(message + wxT("\n"));
}

////////////////////////////////////////////////////////////////////////////////
// delMessage()
//
//    Removes the given message from the 'DBMS Messages' window.
//

void ctlMessageWindow::delMessage( const char * name )
{
    SetValue(wxT(""));
}


wxString ctlMessageWindow::getMessage( int row )
{
    return( GetValue());
}
